@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: MissingH
-version: 1.3.0.1
-id: MissingH-1.3.0.1-af8516ecf9f3f6f260319a04c2ae8afa
-key: Missi_Ib1zDeoXo62AcZUCIuxqeF
+version: 1.3.0.2
+id: MissingH-1.3.0.2-26982253ed22822de88eedb4b5b0e81a
+key: Missi_2DZ5RJkS7wK5BwiMvP3mQY
 license: BSD3
 copyright: Copyright (c) 2004-2014 John Goerzen
 maintainer: John Goerzen <jgoerzen@complete.org>
@@ -35,10 +35,10 @@ exposed-modules:
     System.Posix.Consts System.Debian System.Debian.ControlParser
     Data.MIME.Types System.Console.GetOpt.Utils
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/MissingH-1.3.0.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/MissingH-1.3.0.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/MissingH-1.3.0.1
-hs-libraries: HSMissingH-1.3.0.1-Ib1zDeoXo62AcZUCIuxqeF
+import-dirs: /usr/lib/ghc-7.10.3/site-local/MissingH-1.3.0.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/MissingH-1.3.0.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/MissingH-1.3.0.2
+hs-libraries: HSMissingH-1.3.0.2-2DZ5RJkS7wK5BwiMvP3mQY
 depends:
     HUnit-1.3.1.1-21d4c913eac2236e948873e3db41c801
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
@@ -51,7 +51,7 @@ depends:
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
-    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     regex-compat-0.95.1-89e892301603bb8833ca6f1a349f5b4f
